@@ -13,9 +13,11 @@
 
 class AbstractResource;
 class Category;
+class KStatusNotifierItem;
 class QWindow;
 class QQmlApplicationEngine;
 class CachedNetworkAccessManagerFactory;
+class TransactionsJob;
 
 class DiscoverObject : public QObject
 {
@@ -45,7 +47,6 @@ public:
 
     bool eventFilter(QObject *object, QEvent *event) override;
 
-    Q_SCRIPTABLE QAction *action(const QString &name) const;
     Q_SCRIPTABLE static QString iconName(const QIcon &icon);
 
     void loadTest(const QUrl &url);
@@ -53,9 +54,11 @@ public:
     static bool isRoot();
     QQuickWindow *rootObject() const;
     void showPassiveNotification(const QString &msg);
+    Q_INVOKABLE void copyTextToClipboard(const QString text);
     QRect initialGeometry() const;
 
     QString describeSources() const;
+    Q_SCRIPTABLE void restore();
 
 public Q_SLOTS:
     void openApplication(const QUrl &app);
@@ -65,6 +68,7 @@ public Q_SLOTS:
     void openLocalPackage(const QUrl &localfile);
 
     void reboot();
+    void rebootNow();
 
 private Q_SLOTS:
     void switchApplicationLanguage();
@@ -76,23 +80,24 @@ Q_SIGNALS:
     void listCategoryInternal(Category *cat);
 
     void compactModeChanged(DiscoverObject::CompactMode compactMode);
-    void preventedClose();
     void unableToFind(const QString &resid);
-    void openErrorPage(const QString &errorMessage);
+    void openErrorPage(const QString &errorMessage, const QString &errorExplanation, const QString &buttonText, const QString &buttonIcon, const QString &buttonURL);
 
 private:
     void showLoadingPage();
     void integrateObject(QObject *object);
+    bool quitWhenIdle();
+    void reconsiderQuit();
     QQmlApplicationEngine *engine() const
     {
         return m_engine;
     }
 
-    QMap<QString, QAction *> m_collection;
     QQmlApplicationEngine *const m_engine;
 
     CompactMode m_mode;
     QScopedPointer<CachedNetworkAccessManagerFactory> m_networkAccessManagerFactory;
+    KStatusNotifierItem *m_sni = nullptr;
 };
 
 #endif // DISCOVEROBJECT_H
