@@ -44,12 +44,13 @@ public:
         FlatpakInstallation *m_installation = nullptr;
     };
 
-    void onFetchUpdatesFinished(Installation *flatpakInstallation, GPtrArray *updates);
+    void onFetchUpdatesFinished(Installation *flatpakInstallation, bool hasUpdates);
     void loadRemoteUpdates(Installation *installation);
     bool setupFlatpakInstallations(GError **error);
     Installation m_user;
     Installation m_system;
     GCancellable *const m_cancellable;
+    bool m_lastHasUpdates = false;
 };
 
 #endif
