@@ -46,6 +46,11 @@ QUrl AbstractResource::donationURL()
     return QUrl();
 }
 
+QUrl AbstractResource::contributeURL()
+{
+    return {};
+}
+
 void AbstractResource::addMetadata(const QString &key, const QJsonValue &value)
 {
     m_metadata.insert(key, value);
@@ -81,6 +86,11 @@ AbstractResourcesBackend *AbstractResource::backend() const
     return static_cast<AbstractResourcesBackend *>(parent());
 }
 
+QObject *AbstractResource::backendObject() const
+{
+    return parent();
+}
+
 QString AbstractResource::status()
 {
     switch (state()) {
@@ -253,7 +263,7 @@ QString AbstractResource::upgradeText() const
     if (installed == available) {
         // Update of the same version; show when old and new are
         // the same (common with Flatpak runtimes)
-        return i18n("Update to version %1", available);
+        return i18nc("@info 'Refresh' is used as a noun here, and %1 is an app's version number", "Refresh of version %1", available);
     } else if (!installed.isEmpty() && !available.isEmpty()) {
         // Old and new version numbers
         // This thing with \u009C is a fancy feature in QML text handling:
@@ -287,4 +297,22 @@ QString AbstractResource::versionString()
     }
 }
 
-#include "moc_AbstractResource.cpp"
+QString AbstractResource::contentRatingDescription() const
+{
+    return {};
+}
+
+AbstractResource::ContentIntensity AbstractResource::contentRatingIntensity() const
+{
+    return Mild;
+}
+
+QString AbstractResource::contentRatingText() const
+{
+    return {};
+}
+
+uint AbstractResource::contentRatingMinimumAge() const
+{
+    return 0;
+}
